@@ -148,7 +148,16 @@ sub _initialize
     #
     if ($self->data_dir) {
 	foreach my $subdir ( qw(obj cache) ) {
-	    my @newdirs = mkpath( File::Spec->catdir( $self->data_dir, $subdir ) , 0, 0775 );
+	    my $makedir = File::Spec->catdir( $self->data_dir, $subdir );
+	    my @newdirs = eval { mkpath( $makedir, 0, 0775 ) };
+	    if ($@) {
+		my $user  = getpwuid($<);
+		my $group = getgrgid($();
+		my $data_dir = $self->data_dir;
+		error "Cannot create directory $makedir. " .
+		      "Perhaps you need to create or set permissions on your data_dir. " .
+		      "e.g. 'chown $user.$group $data_dir'";
+	    }
 	    $self->push_files_written(@newdirs);
 	}
     } else {
@@ -992,9 +1001,12 @@ value indicating whether or not a component exists for that path.
 =item comp_root (comp_root)
 
 This is a convenience method which simply calls the C<comp_root>
-method in the resolver object.  Obviously, if you are using a custom
-resolver class which does not have a C<comp_root> method, then this
-convenience method will not work.
+method in the resolver object, which by default is in the
+HTML::Mason::Resolver::File class.
+
+Obviously, if you are using a custom resolver class which does not
+have a C<comp_root> method, then this convenience method will not
+work.
 
 =for html <a name="item_exec"></a>
 
